/**
 * @file
 * Geolocation Street View formatter Javascript.
 */

(function (Drupal, once) {
  'use strict';

  Drupal.geolocation.streetViewFormatter = Drupal.geolocation.streetViewFormatter || {};

  /**
   * Attach Google Street View formatter functionality.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches Google Street View formatter functionality to relevant elements.
   */
  Drupal.behaviors.geolocationStreetViewFormatter = {
    attach: function (context, drupalSettings) {
      if (typeof Drupal.geolocation.google.addLoadedCallback === 'function') {
        Drupal.geolocation.google.addLoadedCallback(function () {
          Drupal.geolocation.streetViewFormatter.attach(context);
        });

        // Load Google Maps API and execute all callbacks.
        Drupal.geolocation.google.load();
      }
    }
  };

  /**
   * @param {HTMLElement} context Context
   */
  Drupal.geolocation.streetViewFormatter.attach = function (context) {
    var elements = once('geolocation-google-maps-street-view-formatter-processed', '.geolocation-map-wrapper', context);
    elements.forEach(function (mapWrapper, index) {
      // Open Street View when POV is given.
      if (mapWrapper.hasAttribute('data-map-heading') && mapWrapper.hasAttribute('data-map-pitch') && mapWrapper.hasAttribute('data-map-zoom')) {
        var mapId = mapWrapper.id.toString();
        var map = Drupal.geolocation.getMapById(mapId);
        if (!map) {
          return;
        }

        // Street View.
        var panorama = map.googleMap.getStreetView();

        // Configure Street View options.
        panorama.setOptions({
          addressControl: true,
          enableCloseButton: false
        });

        // Set position.
        var position = map.mapMarkers[0].position;
        panorama.setPosition(position);

        // Set POV.
        panorama.setPov({
          heading: Number(mapWrapper.dataset.mapHeading),
          pitch: Number(mapWrapper.dataset.mapPitch),
          zoom: Number(mapWrapper.dataset.mapZoom)
        });
        panorama.setVisible(true);
      }
    });
  }

})(Drupal, once);
